searchData={"items":[{"type":"module","title":"HTTPSpec","doc":"Provides implementation-independent HTTP-related structs.","ref":"HTTPSpec.html"},{"type":"module","title":"Why? - HTTPSpec","doc":"Almost every HTTP client has its own abstractions for request and response.\n\nThese abstractions are enough when solving problems with a particular HTTP\nclient. But, when you are building a package involving HTTP and do not want\nto be tied to a specific HTTP client, these abstractions become limiting.\n\nThis package try to provide implementation-independent HTTP-related structs.\nWith these structs, you can build things involving HTTP, but no actual HTTP\nrequest-response handling is required.","ref":"HTTPSpec.html#module-why"},{"type":"module","title":"Structs - HTTPSpec","doc":"* `HTTPSpec.Request`\n  * `HTTPSpec.Response`","ref":"HTTPSpec.html#module-structs"},{"type":"module","title":"Usage - HTTPSpec","doc":"Build a request struct:\n\n    HTTPSpec.Request.build(options)\n    HTTPSpec.Request.build!(options)\n\nBuild a response struct:\n\n    HTTPSpec.Response.build(options)\n    HTTPSpec.Response.build!(options)","ref":"HTTPSpec.html#module-usage"},{"type":"module","title":"HTTPSpec.Request","doc":"A struct for describing HTTP request.","ref":"HTTPSpec.Request.html"},{"type":"function","title":"HTTPSpec.Request.build/1","doc":"","ref":"HTTPSpec.Request.html#build/1"},{"type":"function","title":"HTTPSpec.Request.build!/1","doc":"","ref":"HTTPSpec.Request.html#build!/1"},{"type":"function","title":"HTTPSpec.Request.delete_header/2","doc":"Deletes the header given by `name`.\n\nAll occurrences of the header are deleted, in case the header is repeated multiple times.","ref":"HTTPSpec.Request.html#delete_header/2"},{"type":"function","title":"Examples - HTTPSpec.Request.delete_header/2","doc":"iex> Request.get_header(request, \"cache-control\")\n    [\"max-age=600\", \"no-transform\"]\n    iex> request = Request.delete_header(req, \"cache-control\")\n    iex> Req.Request.get_header(request, \"cache-control\")\n    []","ref":"HTTPSpec.Request.html#delete_header/2-examples"},{"type":"function","title":"HTTPSpec.Request.get_header/2","doc":"Returns the values of the header specified by `name`.","ref":"HTTPSpec.Request.html#get_header/2"},{"type":"function","title":"Examples - HTTPSpec.Request.get_header/2","doc":"iex> Request.get_header(request, \"accept\")\n    [\"application/json\"]\n    iex> Request.get_header(requset, \"x-unknown\")\n    []","ref":"HTTPSpec.Request.html#get_header/2-examples"},{"type":"function","title":"HTTPSpec.Request.put_header/3","doc":"Puts a request header `name` to `value`.\n\nIf the header was previously set, its value is overwritten.","ref":"HTTPSpec.Request.html#put_header/3"},{"type":"function","title":"Examples - HTTPSpec.Request.put_header/3","doc":"iex> Request.get_header(request, \"accept\")\n    []\n    iex> request = Request.put_header(request, \"accept\", \"application/json\")\n    iex> Request.get_header(request, \"accept\")\n    [\"application/json\"]","ref":"HTTPSpec.Request.html#put_header/3-examples"},{"type":"function","title":"HTTPSpec.Request.put_new_header/3","doc":"Puts a request header `name` to `value` unless already present.\n\nSee `put_header/3` for more information.","ref":"HTTPSpec.Request.html#put_new_header/3"},{"type":"function","title":"Examples - HTTPSpec.Request.put_new_header/3","doc":"iex> request =\n    ...>   request\n    ...>   |> Req.Request.put_new_header(\"accept\", \"application/json\")\n    ...>   |> Req.Request.put_new_header(\"accept\", \"text/html\")\n    iex> Req.Request.get_header(request, \"accept\")\n    [\"application/json\"]","ref":"HTTPSpec.Request.html#put_new_header/3-examples"},{"type":"type","title":"HTTPSpec.Request.body/0","doc":"","ref":"HTTPSpec.Request.html#t:body/0"},{"type":"type","title":"HTTPSpec.Request.headers/0","doc":"","ref":"HTTPSpec.Request.html#t:headers/0"},{"type":"type","title":"HTTPSpec.Request.host/0","doc":"","ref":"HTTPSpec.Request.html#t:host/0"},{"type":"type","title":"HTTPSpec.Request.method/0","doc":"","ref":"HTTPSpec.Request.html#t:method/0"},{"type":"type","title":"HTTPSpec.Request.path/0","doc":"","ref":"HTTPSpec.Request.html#t:path/0"},{"type":"type","title":"HTTPSpec.Request.query/0","doc":"","ref":"HTTPSpec.Request.html#t:query/0"},{"type":"type","title":"HTTPSpec.Request.scheme/0","doc":"","ref":"HTTPSpec.Request.html#t:scheme/0"},{"type":"type","title":"HTTPSpec.Request.t/0","doc":"","ref":"HTTPSpec.Request.html#t:t/0"},{"type":"module","title":"HTTPSpec.Response","doc":"A struct for describing HTTP response.","ref":"HTTPSpec.Response.html"},{"type":"function","title":"HTTPSpec.Response.build/1","doc":"","ref":"HTTPSpec.Response.html#build/1"},{"type":"function","title":"HTTPSpec.Response.build!/1","doc":"","ref":"HTTPSpec.Response.html#build!/1"},{"type":"function","title":"HTTPSpec.Response.get_header/2","doc":"Returns the values of the header specified by `name`.","ref":"HTTPSpec.Response.html#get_header/2"},{"type":"function","title":"Examples - HTTPSpec.Response.get_header/2","doc":"iex> Response.get_header(response, \"content-type\")\n    [\"application/json\"]\n\n    iex> Response.get_header(response, \"x-unknown\")\n    []","ref":"HTTPSpec.Response.html#get_header/2-examples"},{"type":"type","title":"HTTPSpec.Response.body/0","doc":"","ref":"HTTPSpec.Response.html#t:body/0"},{"type":"type","title":"HTTPSpec.Response.headers/0","doc":"","ref":"HTTPSpec.Response.html#t:headers/0"},{"type":"type","title":"HTTPSpec.Response.status/0","doc":"","ref":"HTTPSpec.Response.html#t:status/0"},{"type":"type","title":"HTTPSpec.Response.t/0","doc":"","ref":"HTTPSpec.Response.html#t:t/0"},{"type":"exception","title":"HTTPSpec.ArgumentError","doc":"An error that is returned (or raised) when given options are invalid.","ref":"HTTPSpec.ArgumentError.html"},{"type":"type","title":"HTTPSpec.ArgumentError.t/0","doc":"","ref":"HTTPSpec.ArgumentError.html#t:t/0"},{"type":"extras","title":"HTTPSpec","doc":"# HTTPSpec\n\n[![CI](https://github.com/cozy-elixir/http_spec/actions/workflows/ci.yml/badge.svg)](https://github.com/cozy-elixir/http_spec/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/http_spec.svg)](https://hex.pm/packages/http_spec)\n\nProvides implementation-independent HTTP-related structs.","ref":"readme.html"},{"type":"extras","title":"Installation - HTTPSpec","doc":"Add `:http_spec` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:http_spec,  }\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - HTTPSpec","doc":"For more information, see the [documentation](https://hexdocs.pm/http_spec).","ref":"readme.html#usage"},{"type":"extras","title":"Thanks - HTTPSpec","doc":"- [wojtekmach/req](https://github.com/wojtekmach/req)\n- [inets/httpc from Erlang](https://www.erlang.org/doc/apps/inets/httpc)","ref":"readme.html#thanks"},{"type":"extras","title":"License - HTTPSpec","doc":"[Apache License 2.0](http://www.apache.org/licenses/LICENSE-2.0)","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}